@@ -2,7 +2,6 @@
 """Utility methods for marshmallow."""
 from __future__ import absolute_import, unicode_literals
 
-import collections
 import datetime
 import inspect
 import json
@@ -16,6 +15,7 @@ from pprint import pprint as py_pprint
 
 from marshmallow.compat import OrderedDict, binary_type, text_type
 from marshmallow.compat import get_func_args as compat_get_func_args
+from marshmallow.compat import Mapping, Iterable
 
 
 dateutil_available = False
@@ -51,7 +51,7 @@ def is_generator(obj):
 def is_iterable_but_not_string(obj):
     """Return True if ``obj`` is an iterable object that isn't a string."""
     return (
-        (isinstance(obj, collections.Iterable) and not hasattr(obj, "strip")) or is_generator(obj)
+        (isinstance(obj, Iterable) and not hasattr(obj, "strip")) or is_generator(obj)
     )
 
 
@@ -62,7 +62,7 @@ def is_indexable_but_not_string(obj):
 
 def is_collection(obj):
     """Return True if ``obj`` is a collection type, e.g list, tuple, queryset."""
-    return is_iterable_but_not_string(obj) and not isinstance(obj, collections.Mapping)
+    return is_iterable_but_not_string(obj) and not isinstance(obj, Mapping)
 
 
 def is_instance_or_subclass(val, class_):
@@ -92,6 +92,7 @@ def float_to_decimal(f):
         result = ctx.divide(numerator, denominator)
     return result
 
+
 ZERO_DECIMAL = Decimal()
 
 def decimal_to_fixed(value, precision):
@@ -132,6 +133,7 @@ def pprint(obj, *args, **kwargs):
     else:
         py_pprint(obj, *args, **kwargs)
 
+
 # From pytz: http://pytz.sourceforge.net/
 ZERO = datetime.timedelta(0)
 HOUR = datetime.timedelta(hours=1)
@@ -183,6 +185,7 @@ class UTC(datetime.tzinfo):
     def __str__(self):
         return "UTC"
 
+
 UTC = utc = UTC()  # UTC is a singleton
 
 
@@ -211,6 +214,7 @@ def rfcformat(dt, localtime=False):
     else:
         return local_rfcformat(dt)
 
+
 # From Django
 _iso8601_re = re.compile(
     r'(?P<year>\d{4})-(?P<month>\d{1,2})-(?P<day>\d{1,2})'
